@@ -106,7 +106,7 @@ async def gather(*aws, return_exceptions=False):
             #        # cancel all waiting tasks
             #        raise er
             ts[i] = await ts[i]
-        except Exception as er:
+        except (core.CancelledError, Exception) as er:
             if return_exceptions:
                 ts[i] = er
             else:
